@@ -2,9 +2,13 @@ package DateTime::Format::Natural::Base;
 
 use strict;
 use warnings;
-use base qw(DateTime::Format::Natural::Compat);
+use base qw(
+    DateTime::Format::Natural::Compat
+    DateTime::Format::Natural::Utils
+    DateTime::Format::Natural::Wrappers
+);
 
-our $VERSION = '1.29';
+our $VERSION = '1.32';
 
 use constant MORNING   => '08';
 use constant AFTERNOON => '14';
@@ -71,8 +75,8 @@ sub _daytime_variant
         afternoon => AFTERNOON,
         evening   => EVENING,
     );
-    my $hour = $self->{Opts}{daytime}{$daytime}
-      ? $self->{Opts}{daytime}{$daytime}
+    my $hour = $self->{Daytime}{$daytime}
+      ? $self->{Daytime}{$daytime}
       : $daytimes{$daytime};
     if ($self->_valid_time(hour => $hour)) {
         $self->_set(
@@ -300,8 +304,8 @@ sub _at_time
 {
     my $self = shift;
     my $opts = pop;
-    my $hours = $opts->{hours} || 0;
     my ($time) = @_;
+    my $hours = $opts->{hours} || 0;
     if ($time =~ /:/) {
         my ($hour, $minute) = split /:/, $time;
         if ($self->_valid_time(hour => $hours + $hour, minute => $minute)) {
@@ -327,10 +331,11 @@ sub _time_full
     $self->_register_trace;
     my $opts = pop;
     my ($time) = @_;
+    my $hours = $opts->{hours} || 0;
     my ($hour, $minute, $second) = split /:/, $time;
-    if ($self->_valid_time(hour => $hour, minute => $minute, second => $second)) {
+    if ($self->_valid_time(hour => $hours + $hour, minute => $minute, second => $second)) {
         $self->_set(
-            hour   => $hour,
+            hour   => $hours + $hour,
             minute => $minute,
             second => $second,
         );
